@@ -35,12 +35,12 @@ function(model,print.diff=FALSE,graph=TRUE,warning=25) {
     legend(0.75*nrow(model$model),1.05*max(coeffs.prop),colnames(coeffs.prop),col=1:ncol(coeffs.prop),lty=1)
     lignes <- which(abs(coeffs.prop)>warning)
     if (length(lignes)>0) {
-	colonnes <- integer(length(lignes))
-	for (i in 1:length(lignes)) {
-	  colonnes[i] <- which.max(abs(coeffs.prop[lignes[i],]))
-	}
+	colonnes <- lignes%/%nrow(coeffs.prop)+1
+	lignes <- lignes-(colonnes-1)*nrow(coeffs.prop)
 	ecart <- abs(1.1*max(coeffs.prop)-1.1*min(coeffs.prop))*4/100
-	for (i in 1:length(lignes)) {text(lignes[i],coeffs.prop[lignes[i],colonnes[i]]+ecart*sign(coeffs.prop[lignes[i],colonnes[i]]),lignes[i],cex=0.5)}
+	for (i in 1:length(lignes)) {
+	  text(lignes[i],coeffs.prop[lignes[i],colonnes[i]]+ecart*sign(coeffs.prop[lignes[i],colonnes[i]]),lignes[i],cex=0.5)
+	}
     }
   }
   if (print.diff) {print(coeffs.prop,digits=5)}
